@@ -34,14 +34,16 @@ func TestCPUID(t *testing.T) {
 	t.Log("PhysicalCores:", CPU.PhysicalCores)
 	t.Log("ThreadsPerCore:", CPU.ThreadsPerCore)
 	t.Log("LogicalCores:", CPU.LogicalCores)
-	t.Log("Family", CPU.Family, "Model:", CPU.Model)
-	t.Log("Features:", fmt.Sprintf(strings.Join(CPU.FeatureSet(), ",")))
+	t.Log("Family", CPU.Family, "Model:", CPU.Model, "Stepping:", CPU.Stepping)
+	t.Log("Features:", strings.Join(CPU.FeatureSet(), ","))
 	t.Log("Cacheline bytes:", CPU.CacheLine)
 	t.Log("L1 Instruction Cache:", CPU.Cache.L1I, "bytes")
 	t.Log("L1 Data Cache:", CPU.Cache.L1D, "bytes")
 	t.Log("L2 Cache:", CPU.Cache.L2, "bytes")
 	t.Log("L3 Cache:", CPU.Cache.L3, "bytes")
 	t.Log("Hz:", CPU.Hz, "Hz")
+	t.Log("VM:", CPU.VM())
+	t.Log("BoostFreq:", CPU.BoostFreq, "Hz")
 }
 
 func TestExample(t *testing.T) {
@@ -52,7 +54,7 @@ func TestExample(t *testing.T) {
 	fmt.Println("ThreadsPerCore:", CPU.ThreadsPerCore)
 	fmt.Println("LogicalCores:", CPU.LogicalCores)
 	fmt.Println("Family", CPU.Family, "Model:", CPU.Model, "Vendor ID:", CPU.VendorID)
-	fmt.Println("Features:", fmt.Sprintf(strings.Join(CPU.FeatureSet(), ",")))
+	fmt.Println("Features:", strings.Join(CPU.FeatureSet(), ","))
 	fmt.Println("Cacheline bytes:", CPU.CacheLine)
 	fmt.Println("L1 Data Cache:", CPU.Cache.L1D, "bytes")
 	fmt.Println("L1 Instruction Cache:", CPU.Cache.L1D, "bytes")
@@ -134,6 +136,16 @@ func TestSGX(t *testing.T) {
 	}
 }
 
+// TestAMDMemEncryption tests AMDMemEncryption detection
+func TestAMDMemEncryption(t *testing.T) {
+	got := CPU.AMDMemEncryption.Available
+	expected := CPU.featureSet.inSet(SME) || CPU.featureSet.inSet(SEV)
+	if got != expected {
+		t.Fatalf("AMDMemEncryption: expected %v, got %v", expected, got)
+	}
+	t.Log("AMDMemEncryption Support:", got)
+}
+
 func TestHas(t *testing.T) {
 	Detect()
 	defer Detect()
@@ -241,3 +253,43 @@ func ExampleCPUInfo_Ia32TscAux() {
 	core := ecx & 0xFFF
 	fmt.Println("Chip, Core:", chip, core)
 }
+
+func TestCombineFeatures(t *testing.T) {
+	cpu := CPU
+	for i := FeatureID(0); i < lastID; i++ {
+		if cpu.Has(i) != cpu.HasAll(CombineFeatures(i)) {
+			t.Errorf("id %d:%s mismatch", i, i.String())
+		}
+	}
+}
+
+func BenchmarkFlags(b *testing.B) {
+	var a bool
+	var cpu = CPU
+	b.Run("ids", func(b *testing.B) {
+		for i := 0; i < b.N; i++ {
+			a = cpu.Supports(CMOV, CMPXCHG8, X87, FXSR, MMX, SYSCALL, SSE, SSE2, CX16, LAHF, POPCNT, SSE3, SSE4, SSE42, SSSE3, AVX, AVX2, BMI1, BMI2, F16C, FMA3, LZCNT, MOVBE, OSXSAVE) || a
+		}
+		_ = a
+	})
+	b.Run("features", func(b *testing.B) {
+		f := CombineFeatures(CMOV, CMPXCHG8, X87, FXSR, MMX, SYSCALL, SSE, SSE2, CX16, LAHF, POPCNT, SSE3, SSE4, SSE42, SSSE3, AVX, AVX2, BMI1, BMI2, F16C, FMA3, LZCNT, MOVBE, OSXSAVE)
+		for i := 0; i < b.N; i++ {
+			a = cpu.HasAll(f) || a
+		}
+		_ = a
+	})
+	b.Run("id", func(b *testing.B) {
+		for i := 0; i < b.N; i++ {
+			a = cpu.Has(CMOV) || a
+		}
+		_ = a
+	})
+	b.Run("feature", func(b *testing.B) {
+		f := CombineFeatures(CMOV)
+		for i := 0; i < b.N; i++ {
+			a = cpu.HasAll(f) || a
+		}
+		_ = a
+	})
+}
